\name{summary.whatif}
\alias{summary.whatif}
\title{Summary of "whatif" Object}
\description{
Summarizes the information produced by the function \code{whatif},
an object of class "whatif".  The summary produced is returned as 
an output object and can also be printed to the screen.
}
\usage{
\method{summary}{whatif}(object, ...)
}
\arguments{
  \item{object}{An object of class "whatif", produced by a call to
    the function \code{whatif}.}
}
\value{
An object of class "summary.whatif", a list containing the following five
elements:
  \item{call}{The original call to \code{whatif}.}
  \item{m}{A scalar.  The total number of counterfactuals evaluated.}
  \item{m.inhull}{A scalar.  The number of counterfactuals evaluated
  that are in the convex hull of the observed covariate data.}
  \item{mean.near}{A scalar.  The average percentage of data nearby
  each counterfactual, where the average is taken over all
  counterfactuals.}
  \item{sum.df}{A data frame with three columns and m rows, where m is
  the number of counterfactuals.  The first column, 'cfact', indexes
  the counterfactuals.  The second column, 'in.hull', contains the
  results of the convex hull test.  The third column, 'per.near',
  contains the percentage of data points `nearby' each counterfactual.}
}
\references{King, Gary and Langche Zeng.  2006a.  "The Dangers of 
  Extreme Counterfactuals."  \emph{Political Analysis,} forthcoming.
  Preprint available from \url{http://gking.harvard.edu}.

  King, Gary and Langche Zeng.  2006b.  "When Can History Be Our Guide?
  The Pitfalls of Counterfactual Inference."  \emph{International Studies Quarterly,}
  forthcoming.  Preprint available from \url{http://gking.harvard.edu}.}
\author{Stoll, Heather \email{hstoll@polsci.ucsb.edu}, King, Gary
  \email{king@harvard.edu} and Zeng, Langche \email{zeng@ucsd.edu}}
\seealso{
  \code{\link{whatif}},
  \code{\link{plot.whatif}},
  \code{\link{print.whatif}},
  \code{\link{print.summary.whatif}}
}
\examples{
##  Create example data sets and counterfactuals
my.cfact <- matrix(rnorm(3*5), ncol = 5)
my.data <- matrix(rnorm(100*5), ncol = 5)

##  Evaluate counterfactuals
my.result <- whatif(data = my.data, cfact = my.cfact)

##  Print summary
summary(my.result)
}
\keyword{print}
